<?php

/**
 * @file
 * Includes configuration control for constantine module.
 */

/**
 * Constantine configuration form.
 */
function constantine_config_form() {
  // Set Title.
  drupal_set_title(t('constantine'));
  $form  = array();
  $form['constantine_update_number_of_constants'] = array(
    '#type' => 'textfield',
    '#title' => 'Records per page',
    '#description' => t("Please update how many constants are needed.
      <br/> We will populate number of constants as per need."),
    '#default_value' => variable_get('constantine_update_number_of_constants', 10),
  );
  $records = variable_get('constantine_update_number_of_constants', 10);
  if (count($records) > 0) {
    $form['constantine_wrapper'] = array(
      '#type' => 'container',
      '#prefix' => '<div class="constantine_wrapper" style="clear:left;">',
      '#suffix' => '</div>',
    );
    for ($rec = 0; $rec < $records; $rec++) {
      $form['constantine_wrapper']['constantine_container_' . $rec] = array(
        '#type' => 'container',
        '#prefix' => '<div class="constantine_container_' . $rec . '" style="clear:left;">',
        '#suffix' => '</div>',
      );
      $form['constantine_wrapper']['constantine_container_' . $rec]['constantine_name_' . $rec] = array(
        '#type' => 'textfield',
        '#title' => t('Constant Name'),
        '#prefix' => '<div class="constantine_field_name" style="float:left;">',
        '#suffix' => '</div>',
        '#description' => t('Please enter in capital letters only'),
        '#default_value' => variable_get('constantine_name_' . $rec, ''),
      );
      $form['constantine_wrapper']['constantine_container_' . $rec]['constantine_name_value_' . $rec] = array(
        '#type' => 'textfield',
        '#title' => t('Constant Value'),
        '#prefix' => '<div class="constantine_field_value" style="float:left; padding-left: 20px;">',
        '#suffix' => '</div>',
        '#description' => t('Please enter the value'),
        '#default_value' => variable_get('constantine_name_value_' . $rec, ''),
      );
      if ($rec == count($records)) {
        $form['constantine_end_wrapper'] = array(
          '#type' => 'container',
          '#prefix' => '<div class="constantine_end_wrapper" style="clear:left;">',
          '#suffix' => '</div>',
        );
      }
    }
  }
  $form['#validate'][] = 'constantine_validate_form_filling';
  $form['#submit'][] = 'constantine_process_constants';
  return system_settings_form($form);
}

/**
 * Validate configuration form.
 */
function constantine_validate_form_filling($form, &$form_state) {
  $records = variable_get('constantine_update_number_of_constants', 10);
  if (count($records) > 0) {
    for ($rec = 0; $rec < $records; $rec++) {
      $name = $form_state['values']['constantine_name_' . $rec];
      $value = $form_state['values']['constantine_name_value_' . $rec];
      if (empty($name) && !empty($value)) {
        form_set_error('constantine_name_' . $rec, t('Row @count: Name is required', array('@count' => $rec + 1)));
      }
      if (!empty($name) && empty($value)) {
        form_set_error('constantine_name_value_' . $rec, t('Row @count: Value is required', array('@count' => $rec + 1)));
      }
    }
  }
}

/**
 * Get values from the forms and perform actions.
 */
function constantine_process_constants($form, &$form_state) {
  $file_name = DRUPAL_ROOT . '/constantine.php';
  if (!file_exists($file_name)) {
    touch($file_name);
  }
  $file = fopen($file_name, "w");
  echo fwrite($file, "<?php\n");
  echo fwrite($file, "/**\n * @file\n * Constants Information.\n */\n");
  $records = variable_get('constantine_update_number_of_constants', 10);
  if (count($records) > 0) {
    for ($rec = 0; $rec < $records; $rec++) {
      $name = $form_state['values']['constantine_name_' . $rec];
      $value = $form_state['values']['constantine_name_value_' . $rec];
      if (!empty($name) && !empty($value)) {
        if (is_numeric($value)) {
          $current = 'define("' . $name . '", ' . $value . ');' . "\n";
          echo fwrite($file, $current);
        }
        else {
          $var_get = 'variable_get';
          if (strpos($value, $var_get) === 0) {
            $current = 'define("' . $name . '", ' . $value . ');' . "\n";
          }
          else {
            $current = 'define("' . $name . '", "' . $value . '");' . "\n";
          }
          echo fwrite($file, $current);
        }
      }
    }
  }
  fclose($file);
}
